# font-installer [![PyPI](https://img.shields.io/pypi/v/font-installer?style=flat-square)](https://pypi.org/project/font-installer/)

A simple program that helps to install fonts from:
* [dafont.com](https://dafont.com)
* [fonts.google.com](https://fonts.google.com)


## Installation

### [PyPI](https://pypi.org/project/font-installer/)

```sh
$ pip install font-installer
$ font-installer -h
```

### [Git](https://github.com/ineshbose/font-installer)

```sh
$ pip install git+https://github.com/ineshbose/font-installer.git
```


## Usage

Installing fonts is as easy as browsing on sites, copying the URL, and using

```sh
$ font-installer <url>
$ font-installer https://www.dafont.com/bebas-neue.font       # example
```

It is important that you use **Run as Administrator** (Windows) or **sudo** (Linux) to install. Simply paste the URL of your font and it _just works_! <br>
No need to download the .zip to a directory, extract, install each file manually and delete the downloaded file!